summaryrefslogtreecommitdiffstats
path: root/tests/howsmyssl.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tests/howsmyssl.sh')
-rwxr-xr-xtests/howsmyssl.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/howsmyssl.sh b/tests/howsmyssl.sh
index aba65b3..d9ee89e 100755
--- a/tests/howsmyssl.sh
+++ b/tests/howsmyssl.sh
@@ -2,20 +2,20 @@
#
# Copyright (C) 2019 Libiquity LLC
#
# This file is part of wolfssl-util.
#
# wolfssl-util is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# wolfssl-util is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with wolfssl-util. If not, see <http://www.gnu.org/licenses/>.
+# along with wolfutil. If not, see <http://www.gnu.org/licenses/>.
set -eu
@@ -31,7 +31,7 @@ plan_ 7
json="$(printf 'GET /a/check HTTP/1.1\r\n'$(: \
)'Host: www.howsmyssl.com:443\r\nConnection: close\r\n\r\n' | \
- "${TOP_BUILDDIR}/wolfssl" s_client \
+ "${TOP_BUILDDIR}/wolfutil" s_client \
-connect www.howsmyssl.com:443 \
-servername www.howsmyssl.com | \
sed -n 's/\r$//; /^{/,$p')"
@@ -2,20 +2,20 @@
# Copyright (C) 2019 Libiquity LLC
#
-# This file is part of wolfssl-util.
+# This file is part of wolfutil.
#
@@ -2,20 +2,20 @@
#
-# wolfssl-util is free software: you can redistribute it and/or modify
+# wolfutil is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
@@ -2,20 +2,20 @@
# (at your option) any later version.
#
-# wolfssl-util is distributed in the hope that it will be useful,
+# wolfutil is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the